"""This module contains the general information for FabricNetflowMonExporterRef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FabricNetflowMonExporterRefConsts:
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"


class FabricNetflowMonExporterRef(ManagedObject):
    """This is FabricNetflowMonExporterRef class."""

    consts = FabricNetflowMonExporterRefConsts()
    naming_props = set(['nfMonExporterName'])

    mo_meta = MoMeta("FabricNetflowMonExporterRef", "fabricNetflowMonExporterRef", "flow-exporter-[nf_mon_exporter_name]", VersionMeta.Version221b, "InputOutput", 0x7f, [], ["admin", "ext-lan-config", "ext-lan-policy"], ['fabricNetflowMonitor'], ['faultInst'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "index": MoPropertyMeta("index", "index", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], ["0-2"]),
        "nf_mon_exporter_name": MoPropertyMeta("nf_mon_exporter_name", "nfMonExporterName", "string", VersionMeta.Version221b, MoPropertyMeta.NAMING, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "oper_nf_mon_exporter_name": MoPropertyMeta("oper_nf_mon_exporter_name", "operNfMonExporterName", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "index": "index", 
        "nfMonExporterName": "nf_mon_exporter_name", 
        "operNfMonExporterName": "oper_nf_mon_exporter_name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "switchId": "switch_id", 
    }

    def __init__(self, parent_mo_or_dn, nf_mon_exporter_name, **kwargs):
        self._dirty_mask = 0
        self.nf_mon_exporter_name = nf_mon_exporter_name
        self.child_action = None
        self.index = None
        self.oper_nf_mon_exporter_name = None
        self.sacl = None
        self.status = None
        self.switch_id = None

        ManagedObject.__init__(self, "FabricNetflowMonExporterRef", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ProcessorCacheMemStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ProcessorCacheMemStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ProcessorCacheMemStats(ManagedObject):
    """This is ProcessorCacheMemStats class."""

    consts = ProcessorCacheMemStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorCacheMemStats", "processorCacheMemStats", "cache-mem-stats", VersionMeta.Version412a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['processorUnit'], [], [None])

    prop_meta = {
        "l2_cache_unit_correctable_errors": MoPropertyMeta("l2_cache_unit_correctable_errors", "L2CacheUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors15_min": MoPropertyMeta("l2_cache_unit_correctable_errors15_min", "L2CacheUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors15_min_h": MoPropertyMeta("l2_cache_unit_correctable_errors15_min_h", "L2CacheUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors1_day": MoPropertyMeta("l2_cache_unit_correctable_errors1_day", "L2CacheUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors1_day_h": MoPropertyMeta("l2_cache_unit_correctable_errors1_day_h", "L2CacheUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors1_hour": MoPropertyMeta("l2_cache_unit_correctable_errors1_hour", "L2CacheUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors1_hour_h": MoPropertyMeta("l2_cache_unit_correctable_errors1_hour_h", "L2CacheUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors1_week": MoPropertyMeta("l2_cache_unit_correctable_errors1_week", "L2CacheUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors1_week_h": MoPropertyMeta("l2_cache_unit_correctable_errors1_week_h", "L2CacheUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors2_weeks": MoPropertyMeta("l2_cache_unit_correctable_errors2_weeks", "L2CacheUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_correctable_errors2_weeks_h": MoPropertyMeta("l2_cache_unit_correctable_errors2_weeks_h", "L2CacheUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors": MoPropertyMeta("l2_cache_unit_uncorrectable_errors", "L2CacheUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors15_min": MoPropertyMeta("l2_cache_unit_uncorrectable_errors15_min", "L2CacheUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors15_min_h": MoPropertyMeta("l2_cache_unit_uncorrectable_errors15_min_h", "L2CacheUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors1_day": MoPropertyMeta("l2_cache_unit_uncorrectable_errors1_day", "L2CacheUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors1_day_h": MoPropertyMeta("l2_cache_unit_uncorrectable_errors1_day_h", "L2CacheUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors1_hour": MoPropertyMeta("l2_cache_unit_uncorrectable_errors1_hour", "L2CacheUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("l2_cache_unit_uncorrectable_errors1_hour_h", "L2CacheUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors1_week": MoPropertyMeta("l2_cache_unit_uncorrectable_errors1_week", "L2CacheUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors1_week_h": MoPropertyMeta("l2_cache_unit_uncorrectable_errors1_week_h", "L2CacheUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors2_weeks": MoPropertyMeta("l2_cache_unit_uncorrectable_errors2_weeks", "L2CacheUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l2_cache_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("l2_cache_unit_uncorrectable_errors2_weeks_h", "L2CacheUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors": MoPropertyMeta("l3_cache_unit_correctable_errors", "L3CacheUnitCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors15_min": MoPropertyMeta("l3_cache_unit_correctable_errors15_min", "L3CacheUnitCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors15_min_h": MoPropertyMeta("l3_cache_unit_correctable_errors15_min_h", "L3CacheUnitCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors1_day": MoPropertyMeta("l3_cache_unit_correctable_errors1_day", "L3CacheUnitCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors1_day_h": MoPropertyMeta("l3_cache_unit_correctable_errors1_day_h", "L3CacheUnitCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors1_hour": MoPropertyMeta("l3_cache_unit_correctable_errors1_hour", "L3CacheUnitCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors1_hour_h": MoPropertyMeta("l3_cache_unit_correctable_errors1_hour_h", "L3CacheUnitCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors1_week": MoPropertyMeta("l3_cache_unit_correctable_errors1_week", "L3CacheUnitCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors1_week_h": MoPropertyMeta("l3_cache_unit_correctable_errors1_week_h", "L3CacheUnitCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors2_weeks": MoPropertyMeta("l3_cache_unit_correctable_errors2_weeks", "L3CacheUnitCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_correctable_errors2_weeks_h": MoPropertyMeta("l3_cache_unit_correctable_errors2_weeks_h", "L3CacheUnitCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors": MoPropertyMeta("l3_cache_unit_uncorrectable_errors", "L3CacheUnitUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors15_min": MoPropertyMeta("l3_cache_unit_uncorrectable_errors15_min", "L3CacheUnitUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors15_min_h": MoPropertyMeta("l3_cache_unit_uncorrectable_errors15_min_h", "L3CacheUnitUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors1_day": MoPropertyMeta("l3_cache_unit_uncorrectable_errors1_day", "L3CacheUnitUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors1_day_h": MoPropertyMeta("l3_cache_unit_uncorrectable_errors1_day_h", "L3CacheUnitUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors1_hour": MoPropertyMeta("l3_cache_unit_uncorrectable_errors1_hour", "L3CacheUnitUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors1_hour_h": MoPropertyMeta("l3_cache_unit_uncorrectable_errors1_hour_h", "L3CacheUnitUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors1_week": MoPropertyMeta("l3_cache_unit_uncorrectable_errors1_week", "L3CacheUnitUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors1_week_h": MoPropertyMeta("l3_cache_unit_uncorrectable_errors1_week_h", "L3CacheUnitUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors2_weeks": MoPropertyMeta("l3_cache_unit_uncorrectable_errors2_weeks", "L3CacheUnitUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "l3_cache_unit_uncorrectable_errors2_weeks_h": MoPropertyMeta("l3_cache_unit_uncorrectable_errors2_weeks_h", "L3CacheUnitUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors": MoPropertyMeta("mem_testcorrectable_errors", "MemTestcorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors15_min": MoPropertyMeta("mem_testcorrectable_errors15_min", "MemTestcorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors15_min_h": MoPropertyMeta("mem_testcorrectable_errors15_min_h", "MemTestcorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors1_day": MoPropertyMeta("mem_testcorrectable_errors1_day", "MemTestcorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors1_day_h": MoPropertyMeta("mem_testcorrectable_errors1_day_h", "MemTestcorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors1_hour": MoPropertyMeta("mem_testcorrectable_errors1_hour", "MemTestcorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors1_hour_h": MoPropertyMeta("mem_testcorrectable_errors1_hour_h", "MemTestcorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors1_week": MoPropertyMeta("mem_testcorrectable_errors1_week", "MemTestcorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors1_week_h": MoPropertyMeta("mem_testcorrectable_errors1_week_h", "MemTestcorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors2_weeks": MoPropertyMeta("mem_testcorrectable_errors2_weeks", "MemTestcorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mem_testcorrectable_errors2_weeks_h": MoPropertyMeta("mem_testcorrectable_errors2_weeks_h", "MemTestcorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version412a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version412a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "L2CacheUnitCorrectableErrors": "l2_cache_unit_correctable_errors", 
        "L2CacheUnitCorrectableErrors15Min": "l2_cache_unit_correctable_errors15_min", 
        "L2CacheUnitCorrectableErrors15MinH": "l2_cache_unit_correctable_errors15_min_h", 
        "L2CacheUnitCorrectableErrors1Day": "l2_cache_unit_correctable_errors1_day", 
        "L2CacheUnitCorrectableErrors1DayH": "l2_cache_unit_correctable_errors1_day_h", 
        "L2CacheUnitCorrectableErrors1Hour": "l2_cache_unit_correctable_errors1_hour", 
        "L2CacheUnitCorrectableErrors1HourH": "l2_cache_unit_correctable_errors1_hour_h", 
        "L2CacheUnitCorrectableErrors1Week": "l2_cache_unit_correctable_errors1_week", 
        "L2CacheUnitCorrectableErrors1WeekH": "l2_cache_unit_correctable_errors1_week_h", 
        "L2CacheUnitCorrectableErrors2Weeks": "l2_cache_unit_correctable_errors2_weeks", 
        "L2CacheUnitCorrectableErrors2WeeksH": "l2_cache_unit_correctable_errors2_weeks_h", 
        "L2CacheUnitUncorrectableErrors": "l2_cache_unit_uncorrectable_errors", 
        "L2CacheUnitUncorrectableErrors15Min": "l2_cache_unit_uncorrectable_errors15_min", 
        "L2CacheUnitUncorrectableErrors15MinH": "l2_cache_unit_uncorrectable_errors15_min_h", 
        "L2CacheUnitUncorrectableErrors1Day": "l2_cache_unit_uncorrectable_errors1_day", 
        "L2CacheUnitUncorrectableErrors1DayH": "l2_cache_unit_uncorrectable_errors1_day_h", 
        "L2CacheUnitUncorrectableErrors1Hour": "l2_cache_unit_uncorrectable_errors1_hour", 
        "L2CacheUnitUncorrectableErrors1HourH": "l2_cache_unit_uncorrectable_errors1_hour_h", 
        "L2CacheUnitUncorrectableErrors1Week": "l2_cache_unit_uncorrectable_errors1_week", 
        "L2CacheUnitUncorrectableErrors1WeekH": "l2_cache_unit_uncorrectable_errors1_week_h", 
        "L2CacheUnitUncorrectableErrors2Weeks": "l2_cache_unit_uncorrectable_errors2_weeks", 
        "L2CacheUnitUncorrectableErrors2WeeksH": "l2_cache_unit_uncorrectable_errors2_weeks_h", 
        "L3CacheUnitCorrectableErrors": "l3_cache_unit_correctable_errors", 
        "L3CacheUnitCorrectableErrors15Min": "l3_cache_unit_correctable_errors15_min", 
        "L3CacheUnitCorrectableErrors15MinH": "l3_cache_unit_correctable_errors15_min_h", 
        "L3CacheUnitCorrectableErrors1Day": "l3_cache_unit_correctable_errors1_day", 
        "L3CacheUnitCorrectableErrors1DayH": "l3_cache_unit_correctable_errors1_day_h", 
        "L3CacheUnitCorrectableErrors1Hour": "l3_cache_unit_correctable_errors1_hour", 
        "L3CacheUnitCorrectableErrors1HourH": "l3_cache_unit_correctable_errors1_hour_h", 
        "L3CacheUnitCorrectableErrors1Week": "l3_cache_unit_correctable_errors1_week", 
        "L3CacheUnitCorrectableErrors1WeekH": "l3_cache_unit_correctable_errors1_week_h", 
        "L3CacheUnitCorrectableErrors2Weeks": "l3_cache_unit_correctable_errors2_weeks", 
        "L3CacheUnitCorrectableErrors2WeeksH": "l3_cache_unit_correctable_errors2_weeks_h", 
        "L3CacheUnitUncorrectableErrors": "l3_cache_unit_uncorrectable_errors", 
        "L3CacheUnitUncorrectableErrors15Min": "l3_cache_unit_uncorrectable_errors15_min", 
        "L3CacheUnitUncorrectableErrors15MinH": "l3_cache_unit_uncorrectable_errors15_min_h", 
        "L3CacheUnitUncorrectableErrors1Day": "l3_cache_unit_uncorrectable_errors1_day", 
        "L3CacheUnitUncorrectableErrors1DayH": "l3_cache_unit_uncorrectable_errors1_day_h", 
        "L3CacheUnitUncorrectableErrors1Hour": "l3_cache_unit_uncorrectable_errors1_hour", 
        "L3CacheUnitUncorrectableErrors1HourH": "l3_cache_unit_uncorrectable_errors1_hour_h", 
        "L3CacheUnitUncorrectableErrors1Week": "l3_cache_unit_uncorrectable_errors1_week", 
        "L3CacheUnitUncorrectableErrors1WeekH": "l3_cache_unit_uncorrectable_errors1_week_h", 
        "L3CacheUnitUncorrectableErrors2Weeks": "l3_cache_unit_uncorrectable_errors2_weeks", 
        "L3CacheUnitUncorrectableErrors2WeeksH": "l3_cache_unit_uncorrectable_errors2_weeks_h", 
        "MemTestcorrectableErrors": "mem_testcorrectable_errors", 
        "MemTestcorrectableErrors15Min": "mem_testcorrectable_errors15_min", 
        "MemTestcorrectableErrors15MinH": "mem_testcorrectable_errors15_min_h", 
        "MemTestcorrectableErrors1Day": "mem_testcorrectable_errors1_day", 
        "MemTestcorrectableErrors1DayH": "mem_testcorrectable_errors1_day_h", 
        "MemTestcorrectableErrors1Hour": "mem_testcorrectable_errors1_hour", 
        "MemTestcorrectableErrors1HourH": "mem_testcorrectable_errors1_hour_h", 
        "MemTestcorrectableErrors1Week": "mem_testcorrectable_errors1_week", 
        "MemTestcorrectableErrors1WeekH": "mem_testcorrectable_errors1_week_h", 
        "MemTestcorrectableErrors2Weeks": "mem_testcorrectable_errors2_weeks", 
        "MemTestcorrectableErrors2WeeksH": "mem_testcorrectable_errors2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.l2_cache_unit_correctable_errors = None
        self.l2_cache_unit_correctable_errors15_min = None
        self.l2_cache_unit_correctable_errors15_min_h = None
        self.l2_cache_unit_correctable_errors1_day = None
        self.l2_cache_unit_correctable_errors1_day_h = None
        self.l2_cache_unit_correctable_errors1_hour = None
        self.l2_cache_unit_correctable_errors1_hour_h = None
        self.l2_cache_unit_correctable_errors1_week = None
        self.l2_cache_unit_correctable_errors1_week_h = None
        self.l2_cache_unit_correctable_errors2_weeks = None
        self.l2_cache_unit_correctable_errors2_weeks_h = None
        self.l2_cache_unit_uncorrectable_errors = None
        self.l2_cache_unit_uncorrectable_errors15_min = None
        self.l2_cache_unit_uncorrectable_errors15_min_h = None
        self.l2_cache_unit_uncorrectable_errors1_day = None
        self.l2_cache_unit_uncorrectable_errors1_day_h = None
        self.l2_cache_unit_uncorrectable_errors1_hour = None
        self.l2_cache_unit_uncorrectable_errors1_hour_h = None
        self.l2_cache_unit_uncorrectable_errors1_week = None
        self.l2_cache_unit_uncorrectable_errors1_week_h = None
        self.l2_cache_unit_uncorrectable_errors2_weeks = None
        self.l2_cache_unit_uncorrectable_errors2_weeks_h = None
        self.l3_cache_unit_correctable_errors = None
        self.l3_cache_unit_correctable_errors15_min = None
        self.l3_cache_unit_correctable_errors15_min_h = None
        self.l3_cache_unit_correctable_errors1_day = None
        self.l3_cache_unit_correctable_errors1_day_h = None
        self.l3_cache_unit_correctable_errors1_hour = None
        self.l3_cache_unit_correctable_errors1_hour_h = None
        self.l3_cache_unit_correctable_errors1_week = None
        self.l3_cache_unit_correctable_errors1_week_h = None
        self.l3_cache_unit_correctable_errors2_weeks = None
        self.l3_cache_unit_correctable_errors2_weeks_h = None
        self.l3_cache_unit_uncorrectable_errors = None
        self.l3_cache_unit_uncorrectable_errors15_min = None
        self.l3_cache_unit_uncorrectable_errors15_min_h = None
        self.l3_cache_unit_uncorrectable_errors1_day = None
        self.l3_cache_unit_uncorrectable_errors1_day_h = None
        self.l3_cache_unit_uncorrectable_errors1_hour = None
        self.l3_cache_unit_uncorrectable_errors1_hour_h = None
        self.l3_cache_unit_uncorrectable_errors1_week = None
        self.l3_cache_unit_uncorrectable_errors1_week_h = None
        self.l3_cache_unit_uncorrectable_errors2_weeks = None
        self.l3_cache_unit_uncorrectable_errors2_weeks_h = None
        self.mem_testcorrectable_errors = None
        self.mem_testcorrectable_errors15_min = None
        self.mem_testcorrectable_errors15_min_h = None
        self.mem_testcorrectable_errors1_day = None
        self.mem_testcorrectable_errors1_day_h = None
        self.mem_testcorrectable_errors1_hour = None
        self.mem_testcorrectable_errors1_hour_h = None
        self.mem_testcorrectable_errors1_week = None
        self.mem_testcorrectable_errors1_week_h = None
        self.mem_testcorrectable_errors2_weeks = None
        self.mem_testcorrectable_errors2_weeks_h = None
        self.child_action = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ProcessorCacheMemStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AaaCimcSession ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AaaCimcSessionConsts:
    ADMIN_STATE_ACTIVE = "active"
    ADMIN_STATE_INACTIVE = "inactive"
    INT_DEL_FALSE = "false"
    INT_DEL_NO = "no"
    INT_DEL_TRUE = "true"
    INT_DEL_YES = "yes"
    IS_DELETE_NO = "no"
    IS_DELETE_YES = "yes"
    TYPE_ALL = "all"
    TYPE_KVM = "kvm"
    TYPE_SOL = "sol"
    TYPE_VMEDIA = "vmedia"


class AaaCimcSession(ManagedObject):
    """This is AaaCimcSession class."""

    consts = AaaCimcSessionConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("AaaCimcSession", "aaaCimcSession", "cimc-term-[id]", VersionMeta.Version212a, "InputOutput", 0x7f, [], ["admin"], ['aaaEpUser', 'aaaRemoteUser', 'aaaUser', 'commSnmpUser', 'storageEpUser'], [], ["Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["active", "inactive"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version212a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cimc_addr": MoPropertyMeta("cimc_addr", "cimcAddr", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version212a, MoPropertyMeta.NAMING, 0x8, 1, 32, None, [], []),
        "int_del": MoPropertyMeta("int_del", "intDel", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "is_delete": MoPropertyMeta("is_delete", "isDelete", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["no", "yes"], []),
        "last_updated_time": MoPropertyMeta("last_updated_time", "lastUpdatedTime", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "login_time": MoPropertyMeta("login_time", "loginTime", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "ls_dn": MoPropertyMeta("ls_dn", "lsDn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "pid": MoPropertyMeta("pid", "pid", "uint", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pn_dn": MoPropertyMeta("pn_dn", "pnDn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "priv": MoPropertyMeta("priv", "priv", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "source_addr": MoPropertyMeta("source_addr", "sourceAddr", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["all", "kvm", "sol", "vmedia"], []),
        "user": MoPropertyMeta("user", "user", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "cimcAddr": "cimc_addr", 
        "dn": "dn", 
        "id": "id", 
        "intDel": "int_del", 
        "isDelete": "is_delete", 
        "lastUpdatedTime": "last_updated_time", 
        "loginTime": "login_time", 
        "lsDn": "ls_dn", 
        "pid": "pid", 
        "pnDn": "pn_dn", 
        "priv": "priv", 
        "rn": "rn", 
        "sacl": "sacl", 
        "sourceAddr": "source_addr", 
        "status": "status", 
        "type": "type", 
        "user": "user", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.admin_state = None
        self.child_action = None
        self.cimc_addr = None
        self.int_del = None
        self.is_delete = None
        self.last_updated_time = None
        self.login_time = None
        self.ls_dn = None
        self.pid = None
        self.pn_dn = None
        self.priv = None
        self.sacl = None
        self.source_addr = None
        self.status = None
        self.type = None
        self.user = None

        ManagedObject.__init__(self, "AaaCimcSession", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ComputePsuControl ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputePsuControlConsts:
    CLUSTER_STATE_N_A = "N/A"
    CLUSTER_STATE_NOT_CLUSTERED = "not-clustered"
    CLUSTER_STATE_SLOT_1_MASTER = "slot-1-master"
    CLUSTER_STATE_SLOT_2_MASTER = "slot-2-master"
    CLUSTER_STATE_UNKNOWN = "unknown"
    INPUT_POWER_STATE_LOWER_CRITICAL = "lower-critical"
    INPUT_POWER_STATE_LOWER_NON_CRITICAL = "lower-non-critical"
    INPUT_POWER_STATE_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    INPUT_POWER_STATE_NOT_SUPPORTED = "not-supported"
    INPUT_POWER_STATE_OK = "ok"
    INPUT_POWER_STATE_UNKNOWN = "unknown"
    INPUT_POWER_STATE_UPPER_CRITICAL = "upper-critical"
    INPUT_POWER_STATE_UPPER_NON_CRITICAL = "upper-non-critical"
    INPUT_POWER_STATE_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    INT_ID_NONE = "none"
    MODE_DISABLE = "Disable"
    MODE_ENABLE = "Enable"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_FAILED = "failed"
    OPER_STATE_OK = "ok"
    OPER_STATE_UNKNOWN = "unknown"
    OUTPUT_POWER_STATE_LOWER_CRITICAL = "lower-critical"
    OUTPUT_POWER_STATE_LOWER_NON_CRITICAL = "lower-non-critical"
    OUTPUT_POWER_STATE_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    OUTPUT_POWER_STATE_NOT_SUPPORTED = "not-supported"
    OUTPUT_POWER_STATE_OK = "ok"
    OUTPUT_POWER_STATE_UNKNOWN = "unknown"
    OUTPUT_POWER_STATE_UPPER_CRITICAL = "upper-critical"
    OUTPUT_POWER_STATE_UPPER_NON_CRITICAL = "upper-non-critical"
    OUTPUT_POWER_STATE_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    REDUNDANCY_GRID = "grid"
    REDUNDANCY_N_1 = "n+1"
    REDUNDANCY_NON_REDUNDANT = "non-redundant"
    REDUNDANCY_UNKNOWN = "unknown"


class ComputePsuControl(ManagedObject):
    """This is ComputePsuControl class."""

    consts = ComputePsuControlConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputePsuControl", "computePsuControl", "psu-contr", VersionMeta.Version101e, "InputOutput", 0x7f, [], ["read-only"], ['equipmentChassis'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cluster_state": MoPropertyMeta("cluster_state", "clusterState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A", "not-clustered", "slot-1-master", "slot-2-master", "unknown"], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "input_power_state": MoPropertyMeta("input_power_state", "inputPowerState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version413a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["Disable", "Enable"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_qualifier": MoPropertyMeta("oper_qualifier", "operQualifier", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|ok|redundancy-lost|redundancy-degraded|non-redundant-sufficient-resources|non-redundant-insufficient-resources),){0,5}(defaultValue|ok|redundancy-lost|redundancy-degraded|non-redundant-sufficient-resources|non-redundant-insufficient-resources){0,1}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["degraded", "failed", "ok", "unknown"], []),
        "output_power_state": MoPropertyMeta("output_power_state", "outputPowerState", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["local", "pending-policy", "policy"], []),
        "redundancy": MoPropertyMeta("redundancy", "redundancy", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["grid", "n+1", "non-redundant", "unknown"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "clusterState": "cluster_state", 
        "descr": "descr", 
        "dn": "dn", 
        "inputPowerState": "input_power_state", 
        "intId": "int_id", 
        "mode": "mode", 
        "name": "name", 
        "operQualifier": "oper_qualifier", 
        "operState": "oper_state", 
        "outputPowerState": "output_power_state", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "redundancy": "redundancy", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.cluster_state = None
        self.descr = None
        self.input_power_state = None
        self.int_id = None
        self.mode = None
        self.name = None
        self.oper_qualifier = None
        self.oper_state = None
        self.output_power_state = None
        self.policy_level = None
        self.policy_owner = None
        self.redundancy = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "ComputePsuControl", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorMenloHostPortStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorMenloHostPortStatsConsts:
    MENLO_PORT_INDEX_0 = "0"
    MENLO_PORT_INDEX_0_A = "0_A"
    MENLO_PORT_INDEX_0_B = "0_B"
    MENLO_PORT_INDEX_1 = "1"
    MENLO_PORT_INDEX_1_A = "1_A"
    MENLO_PORT_INDEX_1_B = "1_B"
    MENLO_PORT_INDEX_UNKNOWN = "unknown"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class AdaptorMenloHostPortStats(ManagedObject):
    """This is AdaptorMenloHostPortStats class."""

    consts = AdaptorMenloHostPortStatsConsts()
    naming_props = set(['menloPortIndex'])

    mo_meta = MoMeta("AdaptorMenloHostPortStats", "adaptorMenloHostPortStats", "menlo-host-port-stats-[menlo_port_index]", VersionMeta.Version111j, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['adaptorUnit'], ['adaptorMenloHostPortStatsHist'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "menlo_port_index": MoPropertyMeta("menlo_port_index", "menloPortIndex", "string", VersionMeta.Version111j, MoPropertyMeta.NAMING, None, None, None, None, ["0", "0_A", "0_B", "1", "1_A", "1_B", "unknown"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "rx_pause_cfc": MoPropertyMeta("rx_pause_cfc", "rxPauseCFC", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_cfc_delta": MoPropertyMeta("rx_pause_cfc_delta", "rxPauseCFCDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_cfc_delta_avg": MoPropertyMeta("rx_pause_cfc_delta_avg", "rxPauseCFCDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_cfc_delta_max": MoPropertyMeta("rx_pause_cfc_delta_max", "rxPauseCFCDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_cfc_delta_min": MoPropertyMeta("rx_pause_cfc_delta_min", "rxPauseCFCDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_pfc": MoPropertyMeta("rx_pause_pfc", "rxPausePFC", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_pfc_delta": MoPropertyMeta("rx_pause_pfc_delta", "rxPausePFCDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_pfc_delta_avg": MoPropertyMeta("rx_pause_pfc_delta_avg", "rxPausePFCDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_pfc_delta_max": MoPropertyMeta("rx_pause_pfc_delta_max", "rxPausePFCDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rx_pause_pfc_delta_min": MoPropertyMeta("rx_pause_pfc_delta_min", "rxPausePFCDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "tx_pause_cfc": MoPropertyMeta("tx_pause_cfc", "txPauseCFC", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_cfc_delta": MoPropertyMeta("tx_pause_cfc_delta", "txPauseCFCDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_cfc_delta_avg": MoPropertyMeta("tx_pause_cfc_delta_avg", "txPauseCFCDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_cfc_delta_max": MoPropertyMeta("tx_pause_cfc_delta_max", "txPauseCFCDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_cfc_delta_min": MoPropertyMeta("tx_pause_cfc_delta_min", "txPauseCFCDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_pfc": MoPropertyMeta("tx_pause_pfc", "txPausePFC", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_pfc_delta": MoPropertyMeta("tx_pause_pfc_delta", "txPausePFCDelta", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_pfc_delta_avg": MoPropertyMeta("tx_pause_pfc_delta_avg", "txPausePFCDeltaAvg", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_pfc_delta_max": MoPropertyMeta("tx_pause_pfc_delta_max", "txPausePFCDeltaMax", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "tx_pause_pfc_delta_min": MoPropertyMeta("tx_pause_pfc_delta_min", "txPausePFCDeltaMin", "ulong", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "menloPortIndex": "menlo_port_index", 
        "rn": "rn", 
        "rxPauseCFC": "rx_pause_cfc", 
        "rxPauseCFCDelta": "rx_pause_cfc_delta", 
        "rxPauseCFCDeltaAvg": "rx_pause_cfc_delta_avg", 
        "rxPauseCFCDeltaMax": "rx_pause_cfc_delta_max", 
        "rxPauseCFCDeltaMin": "rx_pause_cfc_delta_min", 
        "rxPausePFC": "rx_pause_pfc", 
        "rxPausePFCDelta": "rx_pause_pfc_delta", 
        "rxPausePFCDeltaAvg": "rx_pause_pfc_delta_avg", 
        "rxPausePFCDeltaMax": "rx_pause_pfc_delta_max", 
        "rxPausePFCDeltaMin": "rx_pause_pfc_delta_min", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "txPauseCFC": "tx_pause_cfc", 
        "txPauseCFCDelta": "tx_pause_cfc_delta", 
        "txPauseCFCDeltaAvg": "tx_pause_cfc_delta_avg", 
        "txPauseCFCDeltaMax": "tx_pause_cfc_delta_max", 
        "txPauseCFCDeltaMin": "tx_pause_cfc_delta_min", 
        "txPausePFC": "tx_pause_pfc", 
        "txPausePFCDelta": "tx_pause_pfc_delta", 
        "txPausePFCDeltaAvg": "tx_pause_pfc_delta_avg", 
        "txPausePFCDeltaMax": "tx_pause_pfc_delta_max", 
        "txPausePFCDeltaMin": "tx_pause_pfc_delta_min", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, menlo_port_index, **kwargs):
        self._dirty_mask = 0
        self.menlo_port_index = menlo_port_index
        self.child_action = None
        self.intervals = None
        self.rx_pause_cfc = None
        self.rx_pause_cfc_delta = None
        self.rx_pause_cfc_delta_avg = None
        self.rx_pause_cfc_delta_max = None
        self.rx_pause_cfc_delta_min = None
        self.rx_pause_pfc = None
        self.rx_pause_pfc_delta = None
        self.rx_pause_pfc_delta_avg = None
        self.rx_pause_pfc_delta_max = None
        self.rx_pause_pfc_delta_min = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.tx_pause_cfc = None
        self.tx_pause_cfc_delta = None
        self.tx_pause_cfc_delta_avg = None
        self.tx_pause_cfc_delta_max = None
        self.tx_pause_cfc_delta_min = None
        self.tx_pause_pfc = None
        self.tx_pause_pfc_delta = None
        self.tx_pause_pfc_delta_avg = None
        self.tx_pause_pfc_delta_max = None
        self.tx_pause_pfc_delta_min = None
        self.update = None

        ManagedObject.__init__(self, "AdaptorMenloHostPortStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ProcTxCounts ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ProcTxCountsConsts:
    ADMIN_STATE_CLEAR_STATS = "clear-stats"
    ADMIN_STATE_LOG_STATS = "log-stats"
    ADMIN_STATE_ON = "on"


class ProcTxCounts(ManagedObject):
    """This is ProcTxCounts class."""

    consts = ProcTxCountsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcTxCounts", "procTxCounts", "tx", VersionMeta.Version101e, "InputOutput", 0x3f, [], ["admin", "read-only"], ['procManager', 'procSvc'], [], ["Get"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["clear-stats", "log-stats", "on"], []),
        "bulked": MoPropertyMeta("bulked", "bulked", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "failed": MoPropertyMeta("failed", "failed", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "retried": MoPropertyMeta("retried", "retried", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "singleton": MoPropertyMeta("singleton", "singleton", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "successfull": MoPropertyMeta("successfull", "successfull", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "total": MoPropertyMeta("total", "total", "uint", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "bulked": "bulked", 
        "childAction": "child_action", 
        "dn": "dn", 
        "failed": "failed", 
        "retried": "retried", 
        "rn": "rn", 
        "sacl": "sacl", 
        "singleton": "singleton", 
        "status": "status", 
        "successfull": "successfull", 
        "total": "total", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_state = None
        self.bulked = None
        self.child_action = None
        self.failed = None
        self.retried = None
        self.sacl = None
        self.singleton = None
        self.status = None
        self.successfull = None
        self.total = None

        ManagedObject.__init__(self, "ProcTxCounts", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorFruCapRef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorFruCapRefConsts:
    IS_SUPPORTED_NO = "no"
    IS_SUPPORTED_YES = "yes"


class AdaptorFruCapRef(ManagedObject):
    """This is AdaptorFruCapRef class."""

    consts = AdaptorFruCapRefConsts()
    naming_props = set(['vendor', 'model', 'revision'])

    mo_meta = MoMeta("AdaptorFruCapRef", "adaptorFruCapRef", "manufacturer-[vendor]-model-[model]-revision-[revision]", VersionMeta.Version141i, "InputOutput", 0xff, [], [""], ['equipmentBladeCapProvider', 'equipmentRackUnitCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "is_supported": MoPropertyMeta("is_supported", "isSupported", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []),
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x10, 1, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x80, 1, 510, None, [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "isSupported": "is_supported", 
        "model": "model", 
        "revision": "revision", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, vendor, model, revision, **kwargs):
        self._dirty_mask = 0
        self.vendor = vendor
        self.model = model
        self.revision = revision
        self.child_action = None
        self.is_supported = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "AdaptorFruCapRef", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ConfigCheckCompatibility ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigCheckCompatibility", "configCheckCompatibility", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "dn": MethodPropertyMeta("Dn", "dn", "ReferenceObject", "Version142b", "InputOutput", False),
    "in_blade_pack_version": MethodPropertyMeta("InBladePackVersion", "inBladePackVersion", "Xs:string", "Version142b", "Input", False),
    "in_detail_result": MethodPropertyMeta("InDetailResult", "inDetailResult", "Xs:string", "Version142b", "Input", False),
    "in_infra_pack_version": MethodPropertyMeta("InInfraPackVersion", "inInfraPackVersion", "Xs:string", "Version142b", "Input", False),
    "in_rack_pack_version": MethodPropertyMeta("InRackPackVersion", "inRackPackVersion", "Xs:string", "Version142b", "Input", False),
    "in_service_pack_bundle_version": MethodPropertyMeta("InServicePackBundleVersion", "inServicePackBundleVersion", "Xs:string", "Version142b", "Input", False),
    "out_config_set": MethodPropertyMeta("OutConfigSet", "outConfigSet", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "dn": "dn",
    "inBladePackVersion": "in_blade_pack_version",
    "inDetailResult": "in_detail_result",
    "inInfraPackVersion": "in_infra_pack_version",
    "inRackPackVersion": "in_rack_pack_version",
    "inServicePackBundleVersion": "in_service_pack_bundle_version",
    "outConfigSet": "out_config_set",
}



"""This module contains the general information for ComputeHealthLedSensorAlarm ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ComputeHealthLedSensorAlarmConsts:
    ALARM_SEVERITY_MINOR = "minor"
    ALARM_SEVERITY_SEVERE = "severe"


class ComputeHealthLedSensorAlarm(ManagedObject):
    """This is ComputeHealthLedSensorAlarm class."""

    consts = ComputeHealthLedSensorAlarmConsts()
    naming_props = set(['sensorId'])

    mo_meta = MoMeta("ComputeHealthLedSensorAlarm", "computeHealthLedSensorAlarm", "sensor-alarm-[sensor_id]", VersionMeta.Version212a, "InputOutput", 0x3f, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], ['equipmentHealthLed'], [], ["Get"])

    prop_meta = {
        "alarm_desc": MoPropertyMeta("alarm_desc", "alarmDesc", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "alarm_severity": MoPropertyMeta("alarm_severity", "alarmSeverity", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["minor", "severe"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version212a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "sensor_id": MoPropertyMeta("sensor_id", "sensorId", "ushort", VersionMeta.Version212a, MoPropertyMeta.NAMING, 0x10, None, None, None, [], []),
        "sensor_name": MoPropertyMeta("sensor_name", "sensorName", "string", VersionMeta.Version212a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version212a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "alarmDesc": "alarm_desc", 
        "alarmSeverity": "alarm_severity", 
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "sensorId": "sensor_id", 
        "sensorName": "sensor_name", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, sensor_id, **kwargs):
        self._dirty_mask = 0
        self.sensor_id = sensor_id
        self.alarm_desc = None
        self.alarm_severity = None
        self.child_action = None
        self.sacl = None
        self.sensor_name = None
        self.status = None

        ManagedObject.__init__(self, "ComputeHealthLedSensorAlarm", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FirmwareBackupVersionHolder ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FirmwareBackupVersionHolderConsts:
    BUNDLE_TYPE_BLADE = "blade"
    BUNDLE_TYPE_CHASSIS = "chassis"
    BUNDLE_TYPE_INFRA = "infra"
    BUNDLE_TYPE_NONE = "none"
    BUNDLE_TYPE_RACK = "rack"


class FirmwareBackupVersionHolder(ManagedObject):
    """This is FirmwareBackupVersionHolder class."""

    consts = FirmwareBackupVersionHolderConsts()
    naming_props = set(['bundleType'])

    mo_meta = MoMeta("FirmwareBackupVersionHolder", "firmwareBackupVersionHolder", "update-backup-version-holder-[bundle_type]", VersionMeta.Version323a, "InputOutput", 0x7f, [], ["admin"], ['firmwareCatalogPack', 'firmwareChassisPack', 'firmwareComputeHostPack', 'firmwareComputeMgmtPack', 'firmwareInfraPack'], ['firmwarePackItem'], ["Get", "Set"])

    prop_meta = {
        "bundle_name": MoPropertyMeta("bundle_name", "bundleName", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "bundle_type": MoPropertyMeta("bundle_type", "bundleType", "string", VersionMeta.Version323a, MoPropertyMeta.NAMING, 0x2, None, None, None, ["blade", "chassis", "infra", "none", "rack"], []),
        "bundle_version": MoPropertyMeta("bundle_version", "bundleVersion", "string", VersionMeta.Version323a, MoPropertyMeta.READ_WRITE, 0x4, 0, 510, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version323a, MoPropertyMeta.INTERNAL, 0x8, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version323a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version323a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "bundleName": "bundle_name", 
        "bundleType": "bundle_type", 
        "bundleVersion": "bundle_version", 
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, bundle_type, **kwargs):
        self._dirty_mask = 0
        self.bundle_type = bundle_type
        self.bundle_name = None
        self.bundle_version = None
        self.child_action = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "FirmwareBackupVersionHolder", parent_mo_or_dn, **kwargs)



"""This module contains the general information for OsEthBondModeBalancedRR ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class OsEthBondModeBalancedRRConsts:
    TYPE_ACTIVE_ACTIVE = "active-active"
    TYPE_ACTIVE_PASSIVE = "active-passive"


class OsEthBondModeBalancedRR(ManagedObject):
    """This is OsEthBondModeBalancedRR class."""

    consts = OsEthBondModeBalancedRRConsts()
    naming_props = set([])

    mo_meta = MoMeta("OsEthBondModeBalancedRR", "osEthBondModeBalancedRR", "eth-bond-mode", VersionMeta.Version302c, "InputOutput", 0x3f, [], ["read-only"], ['osEthBondIntf'], ['osPrimarySlave'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version302c, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "igmp_resend_count": MoPropertyMeta("igmp_resend_count", "igmpResendCount", "ushort", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-255"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version302c, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "pkts_per_slave": MoPropertyMeta("pkts_per_slave", "pktsPerSlave", "ushort", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-65535"]),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version302c, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["active-active", "active-passive"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "igmpResendCount": "igmp_resend_count", 
        "name": "name", 
        "pktsPerSlave": "pkts_per_slave", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.igmp_resend_count = None
        self.name = None
        self.pkts_per_slave = None
        self.sacl = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "OsEthBondModeBalancedRR", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ApeGetSwitchApeFru ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeGetSwitchApeFru", "apeGetSwitchApeFru", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_sw_id": MethodPropertyMeta("InSwId", "inSwId", "Xs:string", "Version142b", "Input", False),
    "out_controller_id": MethodPropertyMeta("OutControllerId", "outControllerId", "Xs:string", "Version142b", "Output", False),
    "out_controller_type": MethodPropertyMeta("OutControllerType", "outControllerType", "Xs:string", "Version142b", "Output", False),
    "out_controller_vendor": MethodPropertyMeta("OutControllerVendor", "outControllerVendor", "Xs:string", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inSwId": "in_sw_id",
    "outControllerId": "out_controller_id",
    "outControllerType": "out_controller_type",
    "outControllerVendor": "out_controller_vendor",
}



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# init logging
import logging

log = logging.getLogger('ucs')
log.setLevel(logging.DEBUG)

# create console handler and set level to debug
ch = logging.StreamHandler()
ch.setLevel(logging.DEBUG)

# create formatter
formatter = logging.Formatter(
    '%(asctime)s - %(name)s - %(levelname)s - %(message)s')

# add formatter to ch
ch.setFormatter(formatter)

# add ch to logger
log.addHandler(ch)

__author__ = 'Cisco Systems Inc'
__email__ = 'ucs-python@cisco.com'
__version__ = '0.9.11'



"""This module contains the general information for MemoryErrorStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class MemoryErrorStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class MemoryErrorStats(ManagedObject):
    """This is MemoryErrorStats class."""

    consts = MemoryErrorStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("MemoryErrorStats", "memoryErrorStats", "error-stats", VersionMeta.Version131c, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['memoryPersistentMemoryUnit', 'memoryUnit'], [], ["Get"])

    prop_meta = {
        "dram_write_data_correctable_crc_errors": MoPropertyMeta("dram_write_data_correctable_crc_errors", "DramWriteDataCorrectableCRCErrors", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors15_min": MoPropertyMeta("dram_write_data_correctable_crc_errors15_min", "DramWriteDataCorrectableCRCErrors15Min", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors15_min_h": MoPropertyMeta("dram_write_data_correctable_crc_errors15_min_h", "DramWriteDataCorrectableCRCErrors15MinH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors1_day": MoPropertyMeta("dram_write_data_correctable_crc_errors1_day", "DramWriteDataCorrectableCRCErrors1Day", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors1_day_h": MoPropertyMeta("dram_write_data_correctable_crc_errors1_day_h", "DramWriteDataCorrectableCRCErrors1DayH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors1_hour": MoPropertyMeta("dram_write_data_correctable_crc_errors1_hour", "DramWriteDataCorrectableCRCErrors1Hour", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors1_hour_h": MoPropertyMeta("dram_write_data_correctable_crc_errors1_hour_h", "DramWriteDataCorrectableCRCErrors1HourH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors1_week": MoPropertyMeta("dram_write_data_correctable_crc_errors1_week", "DramWriteDataCorrectableCRCErrors1Week", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors1_week_h": MoPropertyMeta("dram_write_data_correctable_crc_errors1_week_h", "DramWriteDataCorrectableCRCErrors1WeekH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors2_weeks": MoPropertyMeta("dram_write_data_correctable_crc_errors2_weeks", "DramWriteDataCorrectableCRCErrors2Weeks", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_correctable_crc_errors2_weeks_h": MoPropertyMeta("dram_write_data_correctable_crc_errors2_weeks_h", "DramWriteDataCorrectableCRCErrors2WeeksH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors": MoPropertyMeta("dram_write_data_un_correctable_crc_errors", "DramWriteDataUnCorrectableCRCErrors", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors15_min": MoPropertyMeta("dram_write_data_un_correctable_crc_errors15_min", "DramWriteDataUnCorrectableCRCErrors15Min", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors15_min_h": MoPropertyMeta("dram_write_data_un_correctable_crc_errors15_min_h", "DramWriteDataUnCorrectableCRCErrors15MinH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors1_day": MoPropertyMeta("dram_write_data_un_correctable_crc_errors1_day", "DramWriteDataUnCorrectableCRCErrors1Day", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors1_day_h": MoPropertyMeta("dram_write_data_un_correctable_crc_errors1_day_h", "DramWriteDataUnCorrectableCRCErrors1DayH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors1_hour": MoPropertyMeta("dram_write_data_un_correctable_crc_errors1_hour", "DramWriteDataUnCorrectableCRCErrors1Hour", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors1_hour_h": MoPropertyMeta("dram_write_data_un_correctable_crc_errors1_hour_h", "DramWriteDataUnCorrectableCRCErrors1HourH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors1_week": MoPropertyMeta("dram_write_data_un_correctable_crc_errors1_week", "DramWriteDataUnCorrectableCRCErrors1Week", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors1_week_h": MoPropertyMeta("dram_write_data_un_correctable_crc_errors1_week_h", "DramWriteDataUnCorrectableCRCErrors1WeekH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors2_weeks": MoPropertyMeta("dram_write_data_un_correctable_crc_errors2_weeks", "DramWriteDataUnCorrectableCRCErrors2Weeks", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dram_write_data_un_correctable_crc_errors2_weeks_h": MoPropertyMeta("dram_write_data_un_correctable_crc_errors2_weeks_h", "DramWriteDataUnCorrectableCRCErrors2WeeksH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors": MoPropertyMeta("address_parity_errors", "addressParityErrors", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors15_min": MoPropertyMeta("address_parity_errors15_min", "addressParityErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors15_min_h": MoPropertyMeta("address_parity_errors15_min_h", "addressParityErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors1_day": MoPropertyMeta("address_parity_errors1_day", "addressParityErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors1_day_h": MoPropertyMeta("address_parity_errors1_day_h", "addressParityErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors1_hour": MoPropertyMeta("address_parity_errors1_hour", "addressParityErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors1_hour_h": MoPropertyMeta("address_parity_errors1_hour_h", "addressParityErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors1_week": MoPropertyMeta("address_parity_errors1_week", "addressParityErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors1_week_h": MoPropertyMeta("address_parity_errors1_week_h", "addressParityErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors2_weeks": MoPropertyMeta("address_parity_errors2_weeks", "addressParityErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors2_weeks_h": MoPropertyMeta("address_parity_errors2_weeks_h", "addressParityErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable": MoPropertyMeta("address_parity_errors_correctable", "addressParityErrorsCorrectable", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable15_min": MoPropertyMeta("address_parity_errors_correctable15_min", "addressParityErrorsCorrectable15Min", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable15_min_h": MoPropertyMeta("address_parity_errors_correctable15_min_h", "addressParityErrorsCorrectable15MinH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable1_day": MoPropertyMeta("address_parity_errors_correctable1_day", "addressParityErrorsCorrectable1Day", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable1_day_h": MoPropertyMeta("address_parity_errors_correctable1_day_h", "addressParityErrorsCorrectable1DayH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable1_hour": MoPropertyMeta("address_parity_errors_correctable1_hour", "addressParityErrorsCorrectable1Hour", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable1_hour_h": MoPropertyMeta("address_parity_errors_correctable1_hour_h", "addressParityErrorsCorrectable1HourH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable1_week": MoPropertyMeta("address_parity_errors_correctable1_week", "addressParityErrorsCorrectable1Week", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable1_week_h": MoPropertyMeta("address_parity_errors_correctable1_week_h", "addressParityErrorsCorrectable1WeekH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable2_weeks": MoPropertyMeta("address_parity_errors_correctable2_weeks", "addressParityErrorsCorrectable2Weeks", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_correctable2_weeks_h": MoPropertyMeta("address_parity_errors_correctable2_weeks_h", "addressParityErrorsCorrectable2WeeksH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable": MoPropertyMeta("address_parity_errors_un_correctable", "addressParityErrorsUnCorrectable", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable15_min": MoPropertyMeta("address_parity_errors_un_correctable15_min", "addressParityErrorsUnCorrectable15Min", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable15_min_h": MoPropertyMeta("address_parity_errors_un_correctable15_min_h", "addressParityErrorsUnCorrectable15MinH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable1_day": MoPropertyMeta("address_parity_errors_un_correctable1_day", "addressParityErrorsUnCorrectable1Day", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable1_day_h": MoPropertyMeta("address_parity_errors_un_correctable1_day_h", "addressParityErrorsUnCorrectable1DayH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable1_hour": MoPropertyMeta("address_parity_errors_un_correctable1_hour", "addressParityErrorsUnCorrectable1Hour", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable1_hour_h": MoPropertyMeta("address_parity_errors_un_correctable1_hour_h", "addressParityErrorsUnCorrectable1HourH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable1_week": MoPropertyMeta("address_parity_errors_un_correctable1_week", "addressParityErrorsUnCorrectable1Week", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable1_week_h": MoPropertyMeta("address_parity_errors_un_correctable1_week_h", "addressParityErrorsUnCorrectable1WeekH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable2_weeks": MoPropertyMeta("address_parity_errors_un_correctable2_weeks", "addressParityErrorsUnCorrectable2Weeks", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "address_parity_errors_un_correctable2_weeks_h": MoPropertyMeta("address_parity_errors_un_correctable2_weeks_h", "addressParityErrorsUnCorrectable2WeeksH", "uint", VersionMeta.Version401a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131c, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "ecc_multibit_errors": MoPropertyMeta("ecc_multibit_errors", "eccMultibitErrors", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors15_min": MoPropertyMeta("ecc_multibit_errors15_min", "eccMultibitErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors15_min_h": MoPropertyMeta("ecc_multibit_errors15_min_h", "eccMultibitErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors1_day": MoPropertyMeta("ecc_multibit_errors1_day", "eccMultibitErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors1_day_h": MoPropertyMeta("ecc_multibit_errors1_day_h", "eccMultibitErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors1_hour": MoPropertyMeta("ecc_multibit_errors1_hour", "eccMultibitErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors1_hour_h": MoPropertyMeta("ecc_multibit_errors1_hour_h", "eccMultibitErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors1_week": MoPropertyMeta("ecc_multibit_errors1_week", "eccMultibitErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors1_week_h": MoPropertyMeta("ecc_multibit_errors1_week_h", "eccMultibitErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors2_weeks": MoPropertyMeta("ecc_multibit_errors2_weeks", "eccMultibitErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_multibit_errors2_weeks_h": MoPropertyMeta("ecc_multibit_errors2_weeks_h", "eccMultibitErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors": MoPropertyMeta("ecc_singlebit_errors", "eccSinglebitErrors", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors15_min": MoPropertyMeta("ecc_singlebit_errors15_min", "eccSinglebitErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors15_min_h": MoPropertyMeta("ecc_singlebit_errors15_min_h", "eccSinglebitErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors1_day": MoPropertyMeta("ecc_singlebit_errors1_day", "eccSinglebitErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors1_day_h": MoPropertyMeta("ecc_singlebit_errors1_day_h", "eccSinglebitErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors1_hour": MoPropertyMeta("ecc_singlebit_errors1_hour", "eccSinglebitErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors1_hour_h": MoPropertyMeta("ecc_singlebit_errors1_hour_h", "eccSinglebitErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors1_week": MoPropertyMeta("ecc_singlebit_errors1_week", "eccSinglebitErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors1_week_h": MoPropertyMeta("ecc_singlebit_errors1_week_h", "eccSinglebitErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors2_weeks": MoPropertyMeta("ecc_singlebit_errors2_weeks", "eccSinglebitErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "ecc_singlebit_errors2_weeks_h": MoPropertyMeta("ecc_singlebit_errors2_weeks_h", "eccSinglebitErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors": MoPropertyMeta("mismatch_errors", "mismatchErrors", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors15_min": MoPropertyMeta("mismatch_errors15_min", "mismatchErrors15Min", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors15_min_h": MoPropertyMeta("mismatch_errors15_min_h", "mismatchErrors15MinH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors1_day": MoPropertyMeta("mismatch_errors1_day", "mismatchErrors1Day", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors1_day_h": MoPropertyMeta("mismatch_errors1_day_h", "mismatchErrors1DayH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors1_hour": MoPropertyMeta("mismatch_errors1_hour", "mismatchErrors1Hour", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors1_hour_h": MoPropertyMeta("mismatch_errors1_hour_h", "mismatchErrors1HourH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors1_week": MoPropertyMeta("mismatch_errors1_week", "mismatchErrors1Week", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors1_week_h": MoPropertyMeta("mismatch_errors1_week_h", "mismatchErrors1WeekH", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors2_weeks": MoPropertyMeta("mismatch_errors2_weeks", "mismatchErrors2Weeks", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "mismatch_errors2_weeks_h": MoPropertyMeta("mismatch_errors2_weeks_h", "mismatchErrors2WeeksH", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "DramWriteDataCorrectableCRCErrors": "dram_write_data_correctable_crc_errors", 
        "DramWriteDataCorrectableCRCErrors15Min": "dram_write_data_correctable_crc_errors15_min", 
        "DramWriteDataCorrectableCRCErrors15MinH": "dram_write_data_correctable_crc_errors15_min_h", 
        "DramWriteDataCorrectableCRCErrors1Day": "dram_write_data_correctable_crc_errors1_day", 
        "DramWriteDataCorrectableCRCErrors1DayH": "dram_write_data_correctable_crc_errors1_day_h", 
        "DramWriteDataCorrectableCRCErrors1Hour": "dram_write_data_correctable_crc_errors1_hour", 
        "DramWriteDataCorrectableCRCErrors1HourH": "dram_write_data_correctable_crc_errors1_hour_h", 
        "DramWriteDataCorrectableCRCErrors1Week": "dram_write_data_correctable_crc_errors1_week", 
        "DramWriteDataCorrectableCRCErrors1WeekH": "dram_write_data_correctable_crc_errors1_week_h", 
        "DramWriteDataCorrectableCRCErrors2Weeks": "dram_write_data_correctable_crc_errors2_weeks", 
        "DramWriteDataCorrectableCRCErrors2WeeksH": "dram_write_data_correctable_crc_errors2_weeks_h", 
        "DramWriteDataUnCorrectableCRCErrors": "dram_write_data_un_correctable_crc_errors", 
        "DramWriteDataUnCorrectableCRCErrors15Min": "dram_write_data_un_correctable_crc_errors15_min", 
        "DramWriteDataUnCorrectableCRCErrors15MinH": "dram_write_data_un_correctable_crc_errors15_min_h", 
        "DramWriteDataUnCorrectableCRCErrors1Day": "dram_write_data_un_correctable_crc_errors1_day", 
        "DramWriteDataUnCorrectableCRCErrors1DayH": "dram_write_data_un_correctable_crc_errors1_day_h", 
        "DramWriteDataUnCorrectableCRCErrors1Hour": "dram_write_data_un_correctable_crc_errors1_hour", 
        "DramWriteDataUnCorrectableCRCErrors1HourH": "dram_write_data_un_correctable_crc_errors1_hour_h", 
        "DramWriteDataUnCorrectableCRCErrors1Week": "dram_write_data_un_correctable_crc_errors1_week", 
        "DramWriteDataUnCorrectableCRCErrors1WeekH": "dram_write_data_un_correctable_crc_errors1_week_h", 
        "DramWriteDataUnCorrectableCRCErrors2Weeks": "dram_write_data_un_correctable_crc_errors2_weeks", 
        "DramWriteDataUnCorrectableCRCErrors2WeeksH": "dram_write_data_un_correctable_crc_errors2_weeks_h", 
        "addressParityErrors": "address_parity_errors", 
        "addressParityErrors15Min": "address_parity_errors15_min", 
        "addressParityErrors15MinH": "address_parity_errors15_min_h", 
        "addressParityErrors1Day": "address_parity_errors1_day", 
        "addressParityErrors1DayH": "address_parity_errors1_day_h", 
        "addressParityErrors1Hour": "address_parity_errors1_hour", 
        "addressParityErrors1HourH": "address_parity_errors1_hour_h", 
        "addressParityErrors1Week": "address_parity_errors1_week", 
        "addressParityErrors1WeekH": "address_parity_errors1_week_h", 
        "addressParityErrors2Weeks": "address_parity_errors2_weeks", 
        "addressParityErrors2WeeksH": "address_parity_errors2_weeks_h", 
        "addressParityErrorsCorrectable": "address_parity_errors_correctable", 
        "addressParityErrorsCorrectable15Min": "address_parity_errors_correctable15_min", 
        "addressParityErrorsCorrectable15MinH": "address_parity_errors_correctable15_min_h", 
        "addressParityErrorsCorrectable1Day": "address_parity_errors_correctable1_day", 
        "addressParityErrorsCorrectable1DayH": "address_parity_errors_correctable1_day_h", 
        "addressParityErrorsCorrectable1Hour": "address_parity_errors_correctable1_hour", 
        "addressParityErrorsCorrectable1HourH": "address_parity_errors_correctable1_hour_h", 
        "addressParityErrorsCorrectable1Week": "address_parity_errors_correctable1_week", 
        "addressParityErrorsCorrectable1WeekH": "address_parity_errors_correctable1_week_h", 
        "addressParityErrorsCorrectable2Weeks": "address_parity_errors_correctable2_weeks", 
        "addressParityErrorsCorrectable2WeeksH": "address_parity_errors_correctable2_weeks_h", 
        "addressParityErrorsUnCorrectable": "address_parity_errors_un_correctable", 
        "addressParityErrorsUnCorrectable15Min": "address_parity_errors_un_correctable15_min", 
        "addressParityErrorsUnCorrectable15MinH": "address_parity_errors_un_correctable15_min_h", 
        "addressParityErrorsUnCorrectable1Day": "address_parity_errors_un_correctable1_day", 
        "addressParityErrorsUnCorrectable1DayH": "address_parity_errors_un_correctable1_day_h", 
        "addressParityErrorsUnCorrectable1Hour": "address_parity_errors_un_correctable1_hour", 
        "addressParityErrorsUnCorrectable1HourH": "address_parity_errors_un_correctable1_hour_h", 
        "addressParityErrorsUnCorrectable1Week": "address_parity_errors_un_correctable1_week", 
        "addressParityErrorsUnCorrectable1WeekH": "address_parity_errors_un_correctable1_week_h", 
        "addressParityErrorsUnCorrectable2Weeks": "address_parity_errors_un_correctable2_weeks", 
        "addressParityErrorsUnCorrectable2WeeksH": "address_parity_errors_un_correctable2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "eccMultibitErrors": "ecc_multibit_errors", 
        "eccMultibitErrors15Min": "ecc_multibit_errors15_min", 
        "eccMultibitErrors15MinH": "ecc_multibit_errors15_min_h", 
        "eccMultibitErrors1Day": "ecc_multibit_errors1_day", 
        "eccMultibitErrors1DayH": "ecc_multibit_errors1_day_h", 
        "eccMultibitErrors1Hour": "ecc_multibit_errors1_hour", 
        "eccMultibitErrors1HourH": "ecc_multibit_errors1_hour_h", 
        "eccMultibitErrors1Week": "ecc_multibit_errors1_week", 
        "eccMultibitErrors1WeekH": "ecc_multibit_errors1_week_h", 
        "eccMultibitErrors2Weeks": "ecc_multibit_errors2_weeks", 
        "eccMultibitErrors2WeeksH": "ecc_multibit_errors2_weeks_h", 
        "eccSinglebitErrors": "ecc_singlebit_errors", 
        "eccSinglebitErrors15Min": "ecc_singlebit_errors15_min", 
        "eccSinglebitErrors15MinH": "ecc_singlebit_errors15_min_h", 
        "eccSinglebitErrors1Day": "ecc_singlebit_errors1_day", 
        "eccSinglebitErrors1DayH": "ecc_singlebit_errors1_day_h", 
        "eccSinglebitErrors1Hour": "ecc_singlebit_errors1_hour", 
        "eccSinglebitErrors1HourH": "ecc_singlebit_errors1_hour_h", 
        "eccSinglebitErrors1Week": "ecc_singlebit_errors1_week", 
        "eccSinglebitErrors1WeekH": "ecc_singlebit_errors1_week_h", 
        "eccSinglebitErrors2Weeks": "ecc_singlebit_errors2_weeks", 
        "eccSinglebitErrors2WeeksH": "ecc_singlebit_errors2_weeks_h", 
        "intervals": "intervals", 
        "mismatchErrors": "mismatch_errors", 
        "mismatchErrors15Min": "mismatch_errors15_min", 
        "mismatchErrors15MinH": "mismatch_errors15_min_h", 
        "mismatchErrors1Day": "mismatch_errors1_day", 
        "mismatchErrors1DayH": "mismatch_errors1_day_h", 
        "mismatchErrors1Hour": "mismatch_errors1_hour", 
        "mismatchErrors1HourH": "mismatch_errors1_hour_h", 
        "mismatchErrors1Week": "mismatch_errors1_week", 
        "mismatchErrors1WeekH": "mismatch_errors1_week_h", 
        "mismatchErrors2Weeks": "mismatch_errors2_weeks", 
        "mismatchErrors2WeeksH": "mismatch_errors2_weeks_h", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.dram_write_data_correctable_crc_errors = None
        self.dram_write_data_correctable_crc_errors15_min = None
        self.dram_write_data_correctable_crc_errors15_min_h = None
        self.dram_write_data_correctable_crc_errors1_day = None
        self.dram_write_data_correctable_crc_errors1_day_h = None
        self.dram_write_data_correctable_crc_errors1_hour = None
        self.dram_write_data_correctable_crc_errors1_hour_h = None
        self.dram_write_data_correctable_crc_errors1_week = None
        self.dram_write_data_correctable_crc_errors1_week_h = None
        self.dram_write_data_correctable_crc_errors2_weeks = None
        self.dram_write_data_correctable_crc_errors2_weeks_h = None
        self.dram_write_data_un_correctable_crc_errors = None
        self.dram_write_data_un_correctable_crc_errors15_min = None
        self.dram_write_data_un_correctable_crc_errors15_min_h = None
        self.dram_write_data_un_correctable_crc_errors1_day = None
        self.dram_write_data_un_correctable_crc_errors1_day_h = None
        self.dram_write_data_un_correctable_crc_errors1_hour = None
        self.dram_write_data_un_correctable_crc_errors1_hour_h = None
        self.dram_write_data_un_correctable_crc_errors1_week = None
        self.dram_write_data_un_correctable_crc_errors1_week_h = None
        self.dram_write_data_un_correctable_crc_errors2_weeks = None
        self.dram_write_data_un_correctable_crc_errors2_weeks_h = None
        self.address_parity_errors = None
        self.address_parity_errors15_min = None
        self.address_parity_errors15_min_h = None
        self.address_parity_errors1_day = None
        self.address_parity_errors1_day_h = None
        self.address_parity_errors1_hour = None
        self.address_parity_errors1_hour_h = None
        self.address_parity_errors1_week = None
        self.address_parity_errors1_week_h = None
        self.address_parity_errors2_weeks = None
        self.address_parity_errors2_weeks_h = None
        self.address_parity_errors_correctable = None
        self.address_parity_errors_correctable15_min = None
        self.address_parity_errors_correctable15_min_h = None
        self.address_parity_errors_correctable1_day = None
        self.address_parity_errors_correctable1_day_h = None
        self.address_parity_errors_correctable1_hour = None
        self.address_parity_errors_correctable1_hour_h = None
        self.address_parity_errors_correctable1_week = None
        self.address_parity_errors_correctable1_week_h = None
        self.address_parity_errors_correctable2_weeks = None
        self.address_parity_errors_correctable2_weeks_h = None
        self.address_parity_errors_un_correctable = None
        self.address_parity_errors_un_correctable15_min = None
        self.address_parity_errors_un_correctable15_min_h = None
        self.address_parity_errors_un_correctable1_day = None
        self.address_parity_errors_un_correctable1_day_h = None
        self.address_parity_errors_un_correctable1_hour = None
        self.address_parity_errors_un_correctable1_hour_h = None
        self.address_parity_errors_un_correctable1_week = None
        self.address_parity_errors_un_correctable1_week_h = None
        self.address_parity_errors_un_correctable2_weeks = None
        self.address_parity_errors_un_correctable2_weeks_h = None
        self.child_action = None
        self.ecc_multibit_errors = None
        self.ecc_multibit_errors15_min = None
        self.ecc_multibit_errors15_min_h = None
        self.ecc_multibit_errors1_day = None
        self.ecc_multibit_errors1_day_h = None
        self.ecc_multibit_errors1_hour = None
        self.ecc_multibit_errors1_hour_h = None
        self.ecc_multibit_errors1_week = None
        self.ecc_multibit_errors1_week_h = None
        self.ecc_multibit_errors2_weeks = None
        self.ecc_multibit_errors2_weeks_h = None
        self.ecc_singlebit_errors = None
        self.ecc_singlebit_errors15_min = None
        self.ecc_singlebit_errors15_min_h = None
        self.ecc_singlebit_errors1_day = None
        self.ecc_singlebit_errors1_day_h = None
        self.ecc_singlebit_errors1_hour = None
        self.ecc_singlebit_errors1_hour_h = None
        self.ecc_singlebit_errors1_week = None
        self.ecc_singlebit_errors1_week_h = None
        self.ecc_singlebit_errors2_weeks = None
        self.ecc_singlebit_errors2_weeks_h = None
        self.intervals = None
        self.mismatch_errors = None
        self.mismatch_errors15_min = None
        self.mismatch_errors15_min_h = None
        self.mismatch_errors1_day = None
        self.mismatch_errors1_day_h = None
        self.mismatch_errors1_hour = None
        self.mismatch_errors1_hour_h = None
        self.mismatch_errors1_week = None
        self.mismatch_errors1_week_h = None
        self.mismatch_errors2_weeks = None
        self.mismatch_errors2_weeks_h = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "MemoryErrorStats", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of LoggingSyncOcns ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("LoggingSyncOcns", "loggingSyncOcns", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_from_or_zero": MethodPropertyMeta("InFromOrZero", "inFromOrZero", "Xs:unsignedLong", "Version142b", "Input", False),
    "in_to_or_zero": MethodPropertyMeta("InToOrZero", "inToOrZero", "Xs:unsignedLong", "Version142b", "Input", False),
    "out_stimuli": MethodPropertyMeta("OutStimuli", "outStimuli", "MethodSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inFromOrZero": "in_from_or_zero",
    "inToOrZero": "in_to_or_zero",
    "outStimuli": "out_stimuli",
}



"""This module contains the general information for AdaptorIscsiTargetIf ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorIscsiTargetIfConsts:
    pass


class AdaptorIscsiTargetIf(ManagedObject):
    """This is AdaptorIscsiTargetIf class."""

    consts = AdaptorIscsiTargetIfConsts()
    naming_props = set(['priority'])

    mo_meta = MoMeta("AdaptorIscsiTargetIf", "adaptorIscsiTargetIf", "iscsi-target[priority]", VersionMeta.Version201m, "InputOutput", 0x3f, [], ["read-only"], ['adaptorHostIscsiIf'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dhcp_vendor_id": MoPropertyMeta("dhcp_vendor_id", "dhcpVendorId", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "ip_address": MoPropertyMeta("ip_address", "ipAddress", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []),
        "lun": MoPropertyMeta("lun", "lun", "ushort", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "port_number": MoPropertyMeta("port_number", "portNumber", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "priority": MoPropertyMeta("priority", "priority", "ushort", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dhcpVendorId": "dhcp_vendor_id", 
        "dn": "dn", 
        "fltAggr": "flt_aggr", 
        "ipAddress": "ip_address", 
        "lun": "lun", 
        "name": "name", 
        "portNumber": "port_number", 
        "priority": "priority", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, priority, **kwargs):
        self._dirty_mask = 0
        self.priority = priority
        self.child_action = None
        self.dhcp_vendor_id = None
        self.flt_aggr = None
        self.ip_address = None
        self.lun = None
        self.name = None
        self.port_number = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "AdaptorIscsiTargetIf", parent_mo_or_dn, **kwargs)
